@@ -13,7 +13,7 @@ from scrapy.downloadermiddlewares.redirect import RedirectMiddleware
 from scrapy.downloadermiddlewares.cookies import CookiesMiddleware
 
 
-__version__ = "1.2.7"
+__version__ = "1.2.7.2"
 
 logger = logging.getLogger(__name__)
 
@@ -118,7 +118,7 @@ class RequestSession(object):
     def init_requests(self, wrapped):
         def _wrapper(spider, response, *args, **kwargs):
             for obj in wrapped(spider, response, *args, **kwargs):
-                if isinstance(obj, Request):
+                if isinstance(obj, Request) and not obj.meta.get("no_crawlera_session", False):
                     self.init_request(obj)
                 yield obj
 
@@ -226,7 +226,7 @@ class CrawleraSessionCookiesMiddleware(CookiesMiddleware):
 
     def spider_closed(self, spider):
         if self.retained_requests:
-            self.logger.error(
+            logger.error(
                 f"Request {self.retained_requests[0]} and {len(self.retained_requests) - 1} others"
                 "retained requests were not unqueued."
             )
